@@ -5,7 +5,9 @@ import inspect
 import itertools
 import logging
 import os
+import random
 import re
+import string
 import sys
 import traceback
 import typing as t
@@ -18,8 +20,6 @@ import six
 from cryptography.fernet import Fernet
 from flask import current_app
 
-
-
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -29,7 +29,7 @@ class Singleton(type):
 
     def __call__(cls, *args, **kwargs):
         if cls not in cls._instances:
-            cls._instances[cls] = super(Singleton, cls)\
+            cls._instances[cls] = super(Singleton, cls) \
                 .__call__(*args, **kwargs)
         return cls._instances[cls]
 
@@ -316,6 +316,7 @@ def get_ips(ipv4=True, ipv6=False) -> t.List[t.Tuple[str, int]]:
                     ips.append(ip)
     return ips
 
+
 def bind2gate(bind: t.List[str]) -> t.List[t.Tuple[str, int]]:
     from dimensigon import defaults
     specified_gates = set()
@@ -337,6 +338,7 @@ def bind2gate(bind: t.List[str]) -> t.List[t.Tuple[str, int]]:
             specified_gates.update([gate])
     return list(specified_gates)
 
+
 def clean_string(incoming_string):
     replace_char = '_'
     newstring = incoming_string
@@ -396,8 +398,26 @@ def session_scope(session=None):
 def format_exception(exc: Exception):
     return ''.join(traceback.format_exception(exc, exc, exc.__traceback__))
 
+
 def str_resp(resp: requests.Response):
     try:
         return resp.json()
     except ValueError:
-        return resp.text
\ No newline at end of file
+        return resp.text
+
+
+def get_root(path: str):
+    parent_path = os.path.dirname(os.path.abspath(os.path.expanduser(path)))
+    if path == parent_path:
+        return parent_path
+    else:
+        return get_root(parent_path)
+
+
+def remove_root(path: str):
+    return path.lstrip(get_root(path))
+
+
+def get_random_string(length=8):
+    letters = string.ascii_lowercase + string.digits
+    return ''.join(random.choice(letters) for i in range(length))
\ No newline at end of file
